/**
 * HM acquire - software for reading out HAMEG digital storage
 * oscilloscopes.
 *         
 * Copyright (C) 2007 -- 2018 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General
 * Public License along with this program; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin St,
 * Fifth Floor, Boston, MA 02110, USA
 *
 * Contact the author via
 * LSto@opppf.de
 * http://opppf.de/HMacquire/
 */


#ifndef HM_CONSTANTS
#define HM_CONSTANTS


/* ----------------------------------------------------------------------
				 Y amplifyer
 ---------------------------------------------------------------------- */

/* Y amplification in DDF */
const double HM_Y_V_DIV[] = 
{  1e-3,   2e-3,   5e-3, 
  10e-3,  20e-3,  50e-3, 
 100e-3, 200e-3, 500e-3, 
   1,      2,      5, 
  10,     20 };

/* Mask to get Y amplification from DDF */
#define HM_Y_MASK 0x0f

/* Maximum index for Y_V_DIV */
#define HM_Y_MAX 13

/* Bit indicating the channel being on in DDF */
#define HM_Y_ON 0x10

/* Bit indication inverted input */
#define HM_Y_INV 0x20

/* Bit indication AC coupling */
#define HM_Y_AC 0x40

/* Bit indicating ADD mode */
#define HM_ADD 0x08

/* ----------------------------------------------------------------------
				   timebase
 ---------------------------------------------------------------------- */

/* Timebase in DDF */
const double HM_T_s_DIV[] =
{                  50e-9, 
  100e-9, 200e-9, 500e-9,
    1e-6,   2e-6,   5e-6,
   10e-6,  20e-6,  50e-6,
  100e-6, 200e-6, 500e-6,
    1e-3,   2e-3,   5e-3,
   10e-3,  20e-3,  50e-3,
  100e-3, 200e-3, 500e-3,
    1   ,   2   ,   5   ,
   10   ,  20   ,  50   ,
  100 };

/* Mask to get T from DDF */
#define HM_T_MASK 0x1f

/* Maximum index for T_s_DIV */
#define HM_T_MAX 0x1C

/* Timebase in HORMODE */
#define HM_TB_MASK 0x07
#define HM_TBA 0x00

/* Store mode in HORMODE */
#define HM_STORE 0x10

/* XY mode in HORMODE */
#define HM_XY 0x40

#endif

